;;;  .emacs configuration file
;;
;; 3 Apr 1997
;; Choi Jun Ho <junker@jazz.snu.ac.kr>
;;
;; made from xemacs-19.13 sample and other samples
;; for hanemacs, some addition is supported.

;;;; set input method toggle key to 'Shift-Space'
(global-set-key [?\S- ] 'toggle-input-method)

;;;; From Mr. Shin's FAQ
;;;; and jay's setup <http://pllab.kaist.ac.kr/~jay>
;; General korean langauge environment setting
(require 'cl)
(when enable-multibyte-characters
  (set-language-environment "Korean")
  (setq-default file-name-coding-system 'euc-kr)
  ;; comment out if you use 3 bulsik
  ;(setq default-korean-keyboard "2")
  (setq input-method-verbose-flag nil
        input-method-highlight-flag nil)
  ;;;; give highest priority to euc-kr
  (prefer-coding-system 'euc-kr)
  (set-default-coding-systems 'euc-kr)
  (when window-system
    (global-set-key "\C-\\" 'undefined))
  (add-hook 'quail-inactivate-hook 'delete-quail-completions)
  (defun delete-quail-completions ()
    (when (get-buffer "*Quail Completions*")
      (kill-buffer "*Quail Completions*")))

  (unless window-system
    (menu-bar-mode -1)
    (set-keyboard-coding-system 'nil)
    (set-terminal-coding-system 'euc-kr))

  (set-selection-coding-system 'euc-kr)

  ;; Hangul Mail setting
  (setq-default sendmail-coding-system 'euc-kr)

  ;; turn off C-h during input
  (eval-after-load "quail"
    '(progn
      (define-key quail-translation-keymap "\C-h"
        'quail-delete-last-char)
      (define-key quail-translation-keymap "\C-?"
        'quail-translation-help))))

;; For use of `emacs -nw' in Korean terminal emulator
(if (and (null window-system) (null noninteractive))
    (progn
      (set-keyboard-coding-system 'euc-kr)
      (set-terminal-coding-system 'euc-kr)))

;; forcing codesets
(setq gnus-newsgroup-coding-systems
      '(("^tw\\." chinese-big5 . chinese-big5)
       ("^relcom" cyrillic-koi8 . cyrillic-koi8)
       ("^soc\\.culture\\.vietnamese" nil . vietnamese-viqr)
       ("^alt\\.chinese\\.text\\.big5" chinese-big5 . chinese-big5)
       ("^alt\\.hk" chinese-hz . chinese-hz)
       ("^alt\\.chinese\\.text" chinese-hz . chinese-hz)
       ("^han" euc-kr . euc-kr)
       ("^pin" iso-2022-7bit . iso-2022-7bit)
       ("^japan" iso-2022-7bit . iso-2022-7bit)
       ("^tnn" iso-2022-7bit . iso-2022-7bit)
       ("^fj" iso-2022-7bit . iso-2022-7bit)
       ("jp" iso-2022-7bit . iso-2022-7bit)
       ("ja" iso-2022-7bit . iso-2022-7bit)))

; for loading site-lisp files
(setq load-path (cons "/usr/local/share/emacs/site-lisp" load-path))

; for hanemacs
(setq load-path (cons "/usr/local/share/hanemacs/site-lisp" load-path))

; Tell cc-mode not to check for old-style (K&R) function declarations.
; This speeds up indenting a lot.
(setq c-recognize-knr-p nil)

; Change the indentation amount to 4 spaces instead of 2.
; You have to do it in this complicated way because of the
; strange way the cc-mode initializes the value of `c-basic-offset'.
;
(add-hook 'c-mode-hook (lambda () (setq c-basic-offset 2)))

; for hanemacs hanja conversion
;
;(global-set-key [f9] 'split-hanja-window)
;(global-set-key [f8] 'delete-hanja-window)

; prevents ESC-ESC
;
(put 'eval-expression 'disabled nil)
;(setq text-mode-hook 'turn-on-auto-fill)

; autoloading modes
;
;(autoload 'html-mode "html-mode" "HTML major mode." t)
;(autoload 'html-helper-mode "html-helper-mode" "Yay HTML" t)
;(autoload 'perl-mode "cperl-mode" "alternate mode for editing Perl programs" t)
;(autoload 'java-mode "java-mode" "java mode" t nil)
;(autoload 'sgml-mode "sgml-mode" "SGML mode" t)
;(autoload 'po-mode "po-mode")

; font-locks
;
(add-hook 'emacs-lisp-mode-hook 'turn-on-font-lock)
(add-hook 'c-mode-hook 'turn-on-font-lock)
(add-hook 'java-mode-hook 'turn-on-font-lock)
;(add-hook 'html-helper-mode-hook 'turn-on-font-lock)
(add-hook 'perl-mode-hook 'turn-on-font-lock)
(add-hook 'tcl-mode-hook 'turn-on-font-lock)
;(add-hook 'sgml-mode-hook 'turn-on-font-lock)
;(add-hook 'po-mode-hook 'turn-on-font-lock)
;(add-hook 'html-helper-load-hook '(lambda () (require 'html-font)))

; each mode according to extension
;
(setq auto-mode-alist (mapcar 'purecopy
                              '(("\\.c$" . c-mode)
                                ("\\.h$" . c++-mode)
				("\\.cc$" . c++-mode)
                                ("\\.tex$" . LaTeX-mode)
                                ("\\.txi$" . Texinfo-mode)
                                ("\\.el$" . emacs-lisp-mode)
                                ("\.emacs$" . emacs-lisp-mode)
                                ("\\.a$" . c-mode)
				("\\.st$" . smalltalk-mode)
				("\\.html$" . html-helper-mode)
				("\\.m$" . objc-mode)
				("\\.[pP][Llm]$" . perl-mode)
				("\\.java$" . java-mode)
				("\\.sgm$" 'sgml-mode)
				("\\.sgml$"  'sgml-mode)
				("\\.dtd$" 'sgml-mode)
				("\\.po[tx]?\\'\\|\\.po\\." . po-mode)
				)))
 
; keybindings
;
(defvar cursor-map-2 (make-keymap) "for ESC-[")
(fset 'Cursor-Map-2 cursor-map-2)
(define-key esc-map "[" 'Cursor-Map-2)
(define-key esc-map "[A" 'previous-line)
(define-key esc-map "[B" 'next-line)
(define-key esc-map "[C" 'forward-char)
(define-key esc-map "[D" 'backward-char)
(define-key esc-map "[H" 'beginning-of-line)
(define-key esc-map "[Y" 'end-of-line)
(define-key esc-map "[5^" 'scroll-down)
(define-key esc-map "[6^" 'scroll-up)
(define-key esc-map "[[A" 'help-for-help)
(define-key esc-map "[[B" 'byte-compile-file)
(define-key esc-map "[[C" 'isearch-forward)
(define-key esc-map "[[D" 'query-replace-regexp)
(define-key esc-map "[[E" 'eval-defun)
(define-key esc-map "[[F" 'eval-current-buffer)
(define-key esc-map "[[G" 'buffer-menu)
(define-key esc-map "[[H" 'global-set-key)
(define-key esc-map "[[I" 'save-buffer)
(define-key esc-map "[[J" 'save-buffers-kill-emacs)
(define-key esc-map "[2^" 'set-mark-command)
(define-key esc-map "[3^" 'delete-char)
 
 
;;(defun Ctl-C-prefix ()
;;  Ctl-C-keymap)
;;(setq Ctl-C-keymap (make-keymap))
;;(global-set-key "\C-c" (Ctl-C-prefix))
 
;(define-key Ctl-C-keymap "m" 'LaTeX-math-mode)
;(define-key Ctl-C-keymap "o" 'outline-minor-mode)
 
(make-variable-buffer-local 'outline-prefix-char)
(setq-default outline-prefix-char "\C-l")
(make-variable-buffer-local 'outline-regexp)
(setq-default outline-regexp "[*\l]+")
(make-variable-buffer-local 'outline-level-function)
(setq-default outline-level-function 'outline-level-default)
;(autoload 'ispell-word "ispell"
;  "Check the spelling of word in buffer." t)
;(global-set-key "\e$" 'ispell-word)
;(autoload 'ispell-region "ispell"
;  "Check the spelling of region." t)
;(autoload 'ispell-buffer "ispell"
;  "Check the spelling of buffer." t)
;(autoload 'ispell-complete-word "ispell"
;  "Look up current word in dictionary and try to complete it." t)
;(autoload 'ispell-change-dictionary "ispell"
;  "Change ispell dictionary." t)

;;; Emacs-w3 configuration options
;(setq load-path (cons (expand-file-name "/usr/local/share/emacs/site-lisp/w3") load-path))
;(setq load-path (cons (expand-file-name "/usr/local/share/emacs/site-lisp/url") load-path))
;(autoload 'w3-preview-this-buffer "w3" "WWW Previewer" t)
;(autoload 'w3-follow-url-at-point "w3" "Find document at pt" t)
;(autoload 'w3 "w3" "WWW Browser" t)
;(autoload 'w3-open-local "w3" "Open local file for WWW browsing" t)
;(autoload 'w3-fetch "w3" "Open remote file for WWW browsing" t)
;(autoload 'w3-use-hotlist "w3" "Use shortcuts to view WWW docs" t)
;(autoload 'w3-show-hotlist "w3" "Use shortcuts to view WWW docs" t)
;(autoload 'w3-follow-link "w3" "Follow a hypertext link." t)
;(autoload 'w3-batch-fetch "w3" "Batch retrieval of URLs" t)
;(autoload 'url-get-url-at-point "url" "Find the url under the cursor" nil)
;(autoload 'url-file-attributes  "url" "File attributes of a URL" nil)
;(autoload 'url-popup-info "url" "Get info on a URL" t)
;(autoload 'url-retrieve   "url" "Retrieve a URL" nil)
;(autoload 'url-buffer-visiting "url" "Find buffer visiting a URL." nil)
;(autoload 'gopher-dispatch-object "gopher" "Fetch gopher dir" t)
;;; End of Emacs-w3 configuration options

;; for archie
;(autoload 'archie "archie" "Archie interface" t)
;(setq ange-ftp-generate-anonymous-password t)

;; word highlighting - font-lock mode
(setq emacs-lisp-mode-hook '(lambda () (font-lock-mode 1)))

(add-hook 'emacs-lisp-mode-hook 'turn-on-font-lock)
(add-hook 'c-mode-hook 'turn-on-font-lock)
(add-hook 'c++-mode-hook 'turn-on-font-lock)
(add-hook 'lisp-mode-hook 'turn-on-font-lock)
;(add-hook 'latex-mode-hook 'turn-on-font-lock)
;(add-hook 'LaTeX-mode-hook 'turn-on-font-lock)
;(add-hook 'tex-mode-hook 'turn-on-font-lock)
;(add-hook 'html-mode-hook 'turn-on-font-lock)

; local environment in w3
;(setq w3-default-homepage "http://www.yahoo.co.kr/")

; for auc-tex
; do not uncomment this unless you installed auc-tex or installed
; xemacs-19.15
;(require 'tex-site)
;(setq TeX-auto-save t)
;(setq TeX-parse-self t)
;(setq-default TeX-master nil)

; display time in status line
(display-time)

; ksc5601 mode in non-window mode
; do not uncomment this unless you installed ksc5601.el
;
;(if (and (null window-system) (null noninteractive)) 
;    (progn
;      (load-library "ksc5601")
;      (standard-display-ksc5601 t)
;      (substitute-key-definition
;       'backward-delete-char-untabify
;       'ksc5601-backward-delete-char-untabify
;       lisp-interaction-mode-map)))

; html-helper-mode
;(setq html-helper-do-write-file-hooks t)
;(setq html-helper-build-new-buffer t)
;(setq html-helper-address-string 
;  "<a href=\"http://jazz.snu.ac.kr/~junker/\">Choi Jun Ho &lt;junker@jazz.snu.ac.kr&gt;</a>")

; ps-print
;(setq   ps-paper-type 'a4
;        ps-number-of-columns 2
;        ps-landscape-mode t
;)
